#ifndef WCALC_ADD_COMMAS_H
#define WCALC_ADD_COMMAS_H

char *add_commas(const char *input, const int base);

#endif
